package edu.fiu.jtlex.timeml.timeline;

import java.util.List;

/**
 * 
 * Abstraction for indeterminacy results.
 * 
 */
public interface ITimeMLIndeterminacy {
	
    /**
     * Calculates the indeterminacy score.
     *
     * @return A number between 0-1 representing the indeterminacy score
     * @since jTLEX 1.0
     */
    double getIndeterminacyScore();


    /**
     * Return the adjacent indeterminant time pairings.
     *
     * @return A List of the adjacent indeterminant time pairings.
     * @since jTLEX 1.0
     */
    List<String> indeterminantTimePairs();

    /**
     * Returns the indeterminant time points
     *
     * @return A List of the indeterminate time points as Strings.
     * @since jTLEX 1.0
     */
    List<String> indeterminantTimePoints();

    /**
     * Returns the total number of indeterminant time sections.
     *
     * @return The total number of indeterminate time sections.
     * @since jTLEX 1.0
     */
    int getTotalIndeterminantSections();

    /**
     * Returns the timeline's length.
     *
     * @return The timeline's length.
     * @since jTLEX 1.0
     */
    int getTimelineLength();

    /**
     * Returns the number of adjacent pairs.
     *
     * @return The number of adjacent pairs.
     * @since jTLEX 1.0
     */
    int getTotalAdjacentPairs();
}
